using Eco.Gameplay.Skills;

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bicycle")]
    [Weight(5000)]
    [Ecopedia("CavRnMods", "Bicycle", true, InPageTooltip.DynamicTooltip)]
    public partial class BicycleItem : WorldObjectItem<BicycleObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A bicycle for fast travel."); } }
    }
    
    [RequiresSkill(typeof(MechanicsSkill), 1)]
    public class BicycleRecipe : RecipeFamily
    {
        public BicycleRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Bicycle",
                    Localizer.DoStr("Bicycle"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(ClothItem), 4, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),   
                        new IngredientElement(typeof(IronBarItem), 8, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),   
                        new IngredientElement(typeof(IronWheelItem), 2, true),                       
                    },
                    new CraftingElement<BicycleItem>()
                )
            };
            this.ExperienceOnCraft = 10f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(500, typeof(MechanicsSkill)); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(BicycleRecipe), 5, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Bicycle"), typeof(BicycleRecipe));
            CraftingComponent.AddRecipe(typeof(MachinistTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    public partial class BicycleObject : PhysicsWorldObject, IRepresentsItem
    {
        static BicycleObject()
        {
            WorldObject.AddOccupancy<BicycleObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Bicycle"); } }
        public Type RepresentedItemType { get { return typeof(BicycleItem); } }

        private BicycleObject() { }

        /*private int i = 0;
         
        public override void Tick()
        {
            Vector3 vec2 = CavRnHelper.FromQ2(this.Rotation);

            i++;
            
            Log.WriteLine(new LocString("--TICK " + i + "--"));
            Log.WriteLine(new LocString("x: " + vec2.x));
            Log.WriteLine(new LocString("y: " + vec2.y));
            Log.WriteLine(new LocString("z: " + vec2.z));
            Log.WriteLine(new LocString("--------"));

            if ((vec2.x > 75 && vec2.x < 285) || (vec2.z > 120 && vec2.z < 240)) {
                VehicleComponent v = this.GetComponent<VehicleComponent>();

                if (v.Driver != null)
                {
                    Log.WriteLine(new LocString("--------"));
                    Log.WriteLine(new LocString("x: " + vec2.x));
                    Log.WriteLine(new LocString("y: " + vec2.y));
                    Log.WriteLine(new LocString("z: " + vec2.z));
                    Log.WriteLine(new LocString("--------"));
                    
                    v.Driver.InfoBoxLocStr("You have been ejected.");
                    
                    v.Dismount(v.Driver.ID);
                }
            }
        }*/

        protected override void Initialize()
        {
            base.Initialize();

            this.GetComponent<VehicleComponent>().Initialize(22, 0, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(0.25f);           
        }
    }
}
