namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bicycle LightBlue")]
    [Weight(5000)]
    [Ecopedia("CavRnMods", "Bicycle", true, InPageTooltip.DynamicTooltip)]
    [Tag("ColoredBicycle")]
    public partial class BicycleLightBlueItem : WorldObjectItem<BicycleLightBlueObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A light blue bicycle for fast travel."); } }
    }
    
    public class PaintBicycleLightBlueRecipe : RecipeFamily
    {
        public PaintBicycleLightBlueRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Bicycle LightBlue",
                    Localizer.DoStr("Paint Bicycle LightBlue"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(BicycleItem), 1, true), 
                        new IngredientElement(typeof(CamasBulbItem), 6, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),
                        new IngredientElement(typeof(LimestoneItem), 4, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),                       
                    },
                    new CraftingElement<BicycleLightBlueItem>()
                )
            };
            this.ExperienceOnCraft = 0.05f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(125, typeof(MechanicsSkill)); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintBicycleLightBlueRecipe), 2.5f, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Paint Bicycle LightBlue"), typeof(PaintBicycleLightBlueRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    public partial class BicycleLightBlueObject : PhysicsWorldObject, IRepresentsItem
    {
        static BicycleLightBlueObject()
        {
            WorldObject.AddOccupancy<BicycleLightBlueObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Bicycle LightBlue"); } }
        public Type RepresentedItemType { get { return typeof(BicycleLightBlueItem); } }

        
        private BicycleLightBlueObject() { }

        protected override void Initialize()
        {
            base.Initialize();

            this.GetComponent<VehicleComponent>().Initialize(22, 0, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(0.25f);           
        }
    }
}
