namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bicycle Orange")]
    [Weight(5000)]
    [Ecopedia("CavRnMods", "Bicycle", true, InPageTooltip.DynamicTooltip)]
    [Tag("ColoredBicycle")]
    public partial class BicycleOrangeItem : WorldObjectItem<BicycleOrangeObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A orange bicycle for fast travel."); } }
    }
    
    public class PaintBicycleOrangeRecipe : RecipeFamily
    {
        public PaintBicycleOrangeRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Bicycle Orange",
                    Localizer.DoStr("Paint Bicycle Orange"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(BicycleItem), 1, true), 
                        new IngredientElement(typeof(SandstoneItem), 10, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),                       
                    },
                    new CraftingElement<BicycleOrangeItem>()
                )
            };
            this.ExperienceOnCraft = 0.05f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(125, typeof(MechanicsSkill)); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintBicycleOrangeRecipe), 2.5f, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Paint Bicycle Orange"), typeof(PaintBicycleOrangeRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    public partial class BicycleOrangeObject : PhysicsWorldObject, IRepresentsItem
    {
        static BicycleOrangeObject()
        {
            WorldObject.AddOccupancy<BicycleOrangeObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Bicycle Orange"); } }
        public Type RepresentedItemType { get { return typeof(BicycleOrangeItem); } }

        
        private BicycleOrangeObject() { }

        protected override void Initialize()
        {
            base.Initialize();

            this.GetComponent<VehicleComponent>().Initialize(22, 0, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(0.25f);           
        }
    }
}
