namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bicycle Pink")]
    [Weight(5000)]
    [Ecopedia("CavRnMods", "Bicycle", true, InPageTooltip.DynamicTooltip)]
    [Tag("ColoredBicycle")]
    public partial class BicyclePinkItem : WorldObjectItem<BicyclePinkObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A pink bicycle for fast travel."); } }
    }
    
    public class PaintBicyclePinkRecipe : RecipeFamily
    {
        public PaintBicyclePinkRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Bicycle Pink",
                    Localizer.DoStr("Paint Bicycle Pink"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(BicycleItem), 1, true), 
                        new IngredientElement(typeof(BeetItem), 6, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),
                        new IngredientElement(typeof(LimestoneItem), 4, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),                       
                    },
                    new CraftingElement<BicyclePinkItem>()
                )
            };
            this.ExperienceOnCraft = 0.05f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(125, typeof(MechanicsSkill)); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintBicyclePinkRecipe), 2.5f, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Paint Bicycle Pink"), typeof(PaintBicyclePinkRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    public partial class BicyclePinkObject : PhysicsWorldObject, IRepresentsItem
    {
        static BicyclePinkObject()
        {
            WorldObject.AddOccupancy<BicyclePinkObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Bicycle Pink"); } }
        public Type RepresentedItemType { get { return typeof(BicyclePinkItem); } }

        
        private BicyclePinkObject() { }

        protected override void Initialize()
        {
            base.Initialize();

            this.GetComponent<VehicleComponent>().Initialize(22, 0, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(0.25f);           
        }
    }
}
